==> archive_210916_183109.zip: storage/framework/views/396a2b4c17b986eb247763c75c71bb8862fbce2c.php <==
<?php $__env->startSection('morecss'); ?>
<style>
.flex-item{width:120px}
</style>
<?php $__env->stopSection(); ?> 
<?php $__env->startSection('content'); ?>
<div class="container mt-5">
            <div class="row">
               <div class="col-lg-8 col-sm-12 col-12">
                  <div class="mendas-data">
                     <h4 class="mb-5"><span class="text-dark mr-2" style="font-size: 16px;"><sup>Le Presme</sup></span>Modifier</h4>
					 <?php if(session()->has('message')): ?>
    				<div class="alert alertToolsBar alert-info alert-dismissible fade show }}"> 
                    <?php echo session('message'); ?>

                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                      </button>
                    </div>
    			<?php endif; ?>
                     <div class="row">
                        <div class="col-lg-5 col-sm-12 col-12">
						<form method="post" action="<?php echo e(route('config.update')); ?>">
						<?php echo e(csrf_field()); ?> 
						<?php echo e(method_field('patch')); ?>

                              <h6 class="text-color">SOCIETE LE PRISME</h6>

                              <div class="form-group">
                                 <label>Raison sociale</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Le Prisme" name="raison_sociale" id="raison_sociale" value="<?php echo e($societe->raison_sociale); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Enseigne/nom commercial</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Le Prisme" name="enseigne" id="enseigne" value="<?php echo e($societe->enseigne); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Siret</label>
                                 <input type="text" class="form-control form-text-field" placeholder="XXXXX" name="siret" id="siret" value="<?php echo e($societe->siret); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Adresse</label>
                                 <input type="text" class="form-control form-text-field" placeholder="All&eacute;e Hermann Litt&eacute;e Quartier Bac" name="adresse" id="adresse" value="<?php echo e($societe->adresse); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Code Postal</label>
                                 <input type="text" class="form-control form-text-field" placeholder="97224" name="code_postal" id="code_postal" value="<?php echo e($societe->code_postal); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Commune</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Ducos" name="commune" id="commune" value="<?php echo e($societe->commune); ?>">
                              </div>

                              <h6 class="text-color">TARIFS</h6>

                              <div class="form-group">
                                 <label>Tarif frais administratifs (AMO)</label>
                                 <input type="text" class="form-control form-text-field <?php echo e($errors->has('tarif_prestation_ht') ? ' is-invalid' : ''); ?>" name="tarif_prestation_ht" id="tarif_prestation_ht" value="<?php echo e($societe->tarif_prestation_ht); ?>" placeholder="445">
								 <?php if($errors->has('tarif_prestation_ht')): ?> 
										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('tarif_prestation_ht')); ?></strong>
									</span> 
									<?php endif; ?>
                              </div>

                              <div class="form-group">
                                 <label>Tva frais administratifs</label>
                                 <select id="tva_id" name="tva_id"
    									class="form-control form-text-field"> <?php $__currentLoopData = $tvas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $tva): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    									<option value="<?php echo e($tva->id); ?>"
    										<?php if($tva->id==$societe->tva_id): ?> selected
    										<?php endif; ?>><?php echo e($tva->libelle); ?></option> <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    								</select>
								</div>
								<div class="form-group">
                                 <label>Tva travaux</label>
                                 <select id="tva_travaux_id" name="tva_travaux_id"
    									class="form-control form-text-field"> <?php $__currentLoopData = $tvas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $tva): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    									<option value="<?php echo e($tva->id); ?>"
    										<?php if($tva->id==$societe->tva_travaux_id): ?> selected
    										<?php endif; ?>><?php echo e($tva->libelle); ?></option> <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    								</select>
								</div>

                              <h6 class="text-color">INFOMATIONS</h6>

                              <div class="form-group">
                                 <label>Texte r&eacute;glementairet</label>
								 
                                 <input type="text" class="form-control form-text-field" placeholder="445">
                              </div>

                              <div class="form-group">
                                 <label>Tva frais administratifs</label>
								 
                                 <textarea class="form-control form-text-field rounded" rows="3"   id="texte_reglementaire" name="texte_reglementaire" placeholder="T&edot;l: XCC - Fax: XXX SARL au capital de XXXXX &euro; - SIRET XXX XXX XXX XXXX"><?php echo e($societe->texte_reglementaire); ?></textarea>
                              </div>

                              <div class="form-group">
                                 <label>CGV</label>
                                 <textarea class="form-control form-text-field rounded" rows="8" placeholder="Conditions g&eacute;n&eacute;rales de vante" id="cgv" name="cgv" ><?php echo e($societe->cgv); ?></textarea>
                              </div>

                              <h6 class="text-color">S&Eacute;CURIT&Eacute;</h6>

                              <div class="form-bg-mid">
                                 <div class="form-group mb-1 email-overlay">
                                    <input type="text" class="form-control form-text-field <?php echo e($errors->has('email_uniskip') ? ' is-invalid' : ''); ?>" placeholder="Address email Unskip"  name="email_uniskip" id="email_uniskip" value="<?php echo e($societe->email_uniskip); ?>">
                                    <i class="fas fa-envelope"></i>
									<?php if($errors->has('email_uniskip')): ?> 
    										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('email_uniskip')); ?></strong>
    									</span> 
    									<?php endif; ?>
                                 </div>
                              <div class="form-group mb-0 email-overlay">
									<input type="password" class="form-control <?php echo e($errors->has('motdepasse_uniskip') ? ' is-invalid' : ''); ?> form-text-field"  name="motdepasse_uniskip" id="motdepasse_uniskip" value="<?php echo e($societe->motdepasse_uniskip); ?>" placeholder="Mot de passe Unskip"/>
                                    <i class="fas fa-lock"></i>
									<?php if($errors->has('motdepasse_uniskip')): ?> 
    										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('motdepasse_uniskip')); ?></strong>
    									</span> 
    									<?php endif; ?>
                                 </div>
                              </div>

                              <p class="mt-3"><a href="javascript:history.back()" class="text-dark mr-5"><i class="fas fa-times mr-2"></i><?php echo e(__('Cancel')); ?></a> 
							  <i class="fas fa-edit mr-2"></i> <button type="submit" class="text-dark modifier"><?php echo e(__('Update')); ?>

								
</button>
							</p>

                              
                           </form>
                        </div>
                     </div>
					 <!-- <div class="container mt-5 bg-secondary p-3">
					<h4 class="text-white">Changer la bannière</h4>
    					<img src="<?php echo e(asset('images/banniere.gif')); ?>" class="mb-3"/>
    					<form action="<?php echo e(route('changebanniere')); ?>" enctype="multipart/form-data" method="post">
    						<?php echo csrf_field(); ?>
    						<input type="file" name="banniere">
    						<button type="submit" class="btn btn-info" value="changer">Changer</button>
    					</form>
					</div>
				</div>  -->

                     <p><a href="<?php echo e(route('home')); ?>" class="text-dark"><i class="fas fa-chevron-left mr-2"></i>Retour</a></p>
                  </div>
               </div>
            </div>
         </div>

         <img src="<?php echo e(asset('image/PersonnageMécanicien.png')); ?>" class="comman-image-all4">
      </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH C:\xampp\htdocs\HelloDjo_Source\resources\views/admin/config.blade.php ENDPATH**/ ?>

==> archive_211019_102255.zip: storage/framework/views/396a2b4c17b986eb247763c75c71bb8862fbce2c.php <==
<?php $__env->startSection('morecss'); ?>
<style>
.flex-item{width:120px}
</style>
<?php $__env->stopSection(); ?> 
<?php $__env->startSection('content'); ?>
<div class="container mt-5">
            <div class="row">
               <div class="col-lg-8 col-sm-12 col-12">
                  <div class="mendas-data">
                     <h4 class="mb-5"><span class="text-dark mr-2" style="font-size: 16px;"><sup>Le Presme</sup></span>Modifier</h4>
					 <?php if(session()->has('message')): ?>
    				<div class="alert alertToolsBar alert-info alert-dismissible fade show }}"> 
                    <?php echo session('message'); ?>

                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                      </button>
                    </div>
    			<?php endif; ?>
                     <div class="row">
                        <div class="col-lg-5 col-sm-12 col-12">
						<form method="post" action="<?php echo e(route('config.update')); ?>">
						<?php echo e(csrf_field()); ?> 
						<?php echo e(method_field('patch')); ?>

                              <h6 class="text-color">SOCIETE LE PRISME</h6>

                              <div class="form-group">
                                 <label>Raison sociale</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Le Prisme" name="raison_sociale" id="raison_sociale" value="<?php echo e($societe->raison_sociale); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Enseigne/nom commercial</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Le Prisme" name="enseigne" id="enseigne" value="<?php echo e($societe->enseigne); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Siret</label>
                                 <input type="text" class="form-control form-text-field" placeholder="XXXXX" name="siret" id="siret" value="<?php echo e($societe->siret); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Adresse</label>
                                 <input type="text" class="form-control form-text-field" placeholder="All&eacute;e Hermann Litt&eacute;e Quartier Bac" name="adresse" id="adresse" value="<?php echo e($societe->adresse); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Code Postal</label>
                                 <input type="text" class="form-control form-text-field" placeholder="97224" name="code_postal" id="code_postal" value="<?php echo e($societe->code_postal); ?>">
                              </div>

                              <div class="form-group">
                                 <label>Commune</label>
                                 <input type="text" class="form-control form-text-field" placeholder="Ducos" name="commune" id="commune" value="<?php echo e($societe->commune); ?>">
                              </div>

                              <h6 class="text-color">TARIFS</h6>

                              <div class="form-group">
                                 <label>Tarif frais administratifs (AMO)</label>
                                 <input type="text" class="form-control form-text-field <?php echo e($errors->has('tarif_prestation_ht') ? ' is-invalid' : ''); ?>" name="tarif_prestation_ht" id="tarif_prestation_ht" value="<?php echo e($societe->tarif_prestation_ht); ?>" placeholder="445">
								 <?php if($errors->has('tarif_prestation_ht')): ?> 
										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('tarif_prestation_ht')); ?></strong>
									</span> 
									<?php endif; ?>
                              </div>

                              <div class="form-group">
                                 <label>Tva frais administratifs</label>
                                 <select id="tva_id" name="tva_id"
    									class="form-control form-text-field"> <?php $__currentLoopData = $tvas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $tva): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    									<option value="<?php echo e($tva->id); ?>"
    										<?php if($tva->id==$societe->tva_id): ?> selected
    										<?php endif; ?>><?php echo e($tva->libelle); ?></option> <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    								</select>
								</div>
								<div class="form-group">
                                 <label>Tva travaux</label>
                                 <select id="tva_travaux_id" name="tva_travaux_id"
    									class="form-control form-text-field"> <?php $__currentLoopData = $tvas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $tva): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    									<option value="<?php echo e($tva->id); ?>"
    										<?php if($tva->id==$societe->tva_travaux_id): ?> selected
    										<?php endif; ?>><?php echo e($tva->libelle); ?></option> <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
    								</select>
								</div>

                              <h6 class="text-color">INFOMATIONS</h6>

                              <div class="form-group">
                                 <label>Texte r&eacute;glementairet</label>
								 
                                 <input type="text" class="form-control form-text-field" placeholder="445">
                              </div>

                              <div class="form-group">
                                 <label>Tva frais administratifs</label>
								 
                                 <textarea class="form-control form-text-field rounded" rows="3"   id="texte_reglementaire" name="texte_reglementaire" placeholder="T&edot;l: XCC - Fax: XXX SARL au capital de XXXXX &euro; - SIRET XXX XXX XXX XXXX"><?php echo e($societe->texte_reglementaire); ?></textarea>
                              </div>

                              <div class="form-group">
                                 <label>CGV</label>
                                 <textarea class="form-control form-text-field rounded" rows="8" placeholder="Conditions g&eacute;n&eacute;rales de vante" id="cgv" name="cgv" ><?php echo e($societe->cgv); ?></textarea>
                              </div>

                              <h6 class="text-color">S&Eacute;CURIT&Eacute;</h6>

                              <div class="form-bg-mid">
                                 <div class="form-group mb-1 email-overlay">
                                    <input type="text" class="form-control form-text-field <?php echo e($errors->has('email_uniskip') ? ' is-invalid' : ''); ?>" placeholder="Address email Unskip"  name="email_uniskip" id="email_uniskip" value="<?php echo e($societe->email_uniskip); ?>">
                                    <i class="fas fa-envelope"></i>
									<?php if($errors->has('email_uniskip')): ?> 
    										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('email_uniskip')); ?></strong>
    									</span> 
    									<?php endif; ?>
                                 </div>
                              <div class="form-group mb-0 email-overlay">
									<input type="password" class="form-control <?php echo e($errors->has('motdepasse_uniskip') ? ' is-invalid' : ''); ?> form-text-field"  name="motdepasse_uniskip" id="motdepasse_uniskip" value="<?php echo e($societe->motdepasse_uniskip); ?>" placeholder="Mot de passe Unskip"/>
                                    <i class="fas fa-lock"></i>
									<?php if($errors->has('motdepasse_uniskip')): ?> 
    										<span class="invalid-feedback" role="alert"> <strong><?php echo e($errors->first('motdepasse_uniskip')); ?></strong>
    									</span> 
    									<?php endif; ?>
                                 </div>
                              </div>

                              <p class="mt-3"><a href="javascript:history.back()" class="text-dark mr-5"><i class="fas fa-times mr-2"></i><?php echo e(__('Cancel')); ?></a> 
							  <i class="fas fa-edit mr-2"></i> <button type="submit" class="text-dark modifier"><?php echo e(__('Update')); ?>

								
</button>
							</p>

                              
                           </form>
                        </div>
                     </div>
					 <!-- <div class="container mt-5 bg-secondary p-3">
					<h4 class="text-white">Changer la bannière</h4>
    					<img src="<?php echo e(asset('images/banniere.gif')); ?>" class="mb-3"/>
    					<form action="<?php echo e(route('changebanniere')); ?>" enctype="multipart/form-data" method="post">
    						<?php echo csrf_field(); ?>
    						<input type="file" name="banniere">
    						<button type="submit" class="btn btn-info" value="changer">Changer</button>
    					</form>
					</div>
				</div>  -->

                     <p><a href="<?php echo e(route('home')); ?>" class="text-dark"><i class="fas fa-chevron-left mr-2"></i>Retour</a></p>
                  </div>
               </div>
            </div>
         </div>

         <img src="<?php echo e(asset('image/PersonnageMecanicien.png')); ?>" class="comman-image-all4">
      </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH C:\xampp\htdocs\HelloDjo_Source\resources\views/admin/config.blade.php ENDPATH**/ ?>
